@@ -34,11 +34,11 @@ class DiscoverPage : public QWizardPage, public Ui::Discover
     Q_OBJECT
 
 public:
-    explicit DiscoverPage(BlueWizard *parent = 0);
+    explicit DiscoverPage(BlueWizard *parent = nullptr);
 
-    void initializePage() Q_DECL_OVERRIDE;
-    bool isComplete() const Q_DECL_OVERRIDE;
-    int nextId() const Q_DECL_OVERRIDE;
+    void initializePage() override;
+    bool isComplete() const override;
+    int nextId() const override;
 
 private Q_SLOTS:
     void indexSelected(const QModelIndex &index);
